@@ -36,7 +36,6 @@ from . import __version__, utils
 from .embeds import Ark, Embed
 from .error import HTTPException, Forbidden, NotFound, QQServerError, LoginFailure, GatewayNotFound
 from .gateway import QQClientWebSocketResponse
-from .role import Role
 from .types import user, guild, message, channel, member
 from .types.embed import Ark as ArkPayload, Embed as EmbedPayload
 from .types.message import Message
@@ -44,6 +43,10 @@ from .types.permission import (
     Permission as PermissionPayload,
     PermissionDemand as PermissionDemandPayload
 )
+from .types.role import (
+    WrappedRole as WrappedRolePayload,
+    Role as RolePayload
+)
 from .types.schedule import Schedule as SchedulePayload
 from .utils import MISSING
 
@@ -210,13 +213,14 @@ class HTTPClient:
 
                         # the request was successful so just return the text/json
                         if 300 > response.status >= 200:
-                            _log.debug('%s %s 已收到 %s', method, url, data)
+                            if response.status != 204:
+                                _log.debug('%s %s 已收到 %s', method, url, data)
                             return data
 
                         # we've received a 500, 502, or 504, unconditional retry
-                        # if response.status in {500}:
-                        #     await asyncio.sleep(1 + tries * 2)
-                        #     continue
+                        if response.status in (500, 502, 504):
+                            await asyncio.sleep(1 + tries * 2)
+                            continue
 
                         # the usual error cases
                         if response.status in [403, 401]:
@@ -236,7 +240,7 @@ class HTTPClient:
                         continue
                     raise
                 except QQServerError as e:
-                    if tries < 4 and e.code in (620006, ):
+                    if tries < 4 and e.code in (620006,):
                         await asyncio.sleep(1 + tries * 2)
                         continue
                     raise e
@@ -295,12 +299,12 @@ class HTTPClient:
 
     # 身份组管理
 
-    def get_roles(self, guild_id: int) -> Response[List[Role]]:
+    def get_roles(self, guild_id: int) -> Response[List[RolePayload]]:
         return self.request(Route('GET', '/guilds/{guild_id}/roles', guild_id=guild_id))
 
     def edit_role(
             self, guild_id: int, role_id: int, *, reason: Optional[str] = None, **fields: Any
-    ) -> Response[Role]:
+    ) -> Response[RolePayload]:
         r = Route('PATCH', '/guilds/{guild_id}/roles/{role_id}', guild_id=guild_id, role_id=role_id)
         valid_keys = ('name', 'color', 'hoist')
         payload = {"info": {k: v for k, v in fields.items() if k in valid_keys}}
@@ -310,12 +314,13 @@ class HTTPClient:
         r = Route('DELETE', '/guilds/{guild_id}/roles/{role_id}', guild_id=guild_id, role_id=role_id)
         return self.request(r, reason=reason)
 
-    def create_role(self, guild_id: int, *, reason: Optional[str] = None, **fields: Any) -> Response[Role]:
+    def create_role(self, guild_id: int, *, reason: Optional[str] = None, **fields: Any) -> Response[
+        WrappedRolePayload]:
         r = Route('POST', '/guilds/{guild_id}/roles', guild_id=guild_id)
         return self.request(r, json=fields, reason=reason)
 
     def add_role(
-            self, guild_id: int, user_id: int, role_id: int, *, reason: Optional[str] = None
+            self, guild_id: int, user_id: int, role_id: int, channel_id: Optional[int], *, reason: Optional[str] = None
     ) -> Response[None]:
         r = Route(
             'PUT',
@@ -324,10 +329,13 @@ class HTTPClient:
             user_id=user_id,
             role_id=role_id,
         )
+        if channel_id:
+            payload = {'channel': {'id': str(channel_id)}}
+            return self.request(r, json=payload, reason=reason)
         return self.request(r, reason=reason)
 
     def remove_role(
-            self, guild_id: int, user_id: int, role_id: int, *, reason: Optional[str] = None
+            self, guild_id: int, user_id: int, role_id: int, channel_id: Optional[int], *, reason: Optional[str] = None
     ) -> Response[None]:
         r = Route(
             'DELETE',
@@ -336,6 +344,9 @@ class HTTPClient:
             user_id=user_id,
             role_id=role_id,
         )
+        if channel_id:
+            payload = {'channel': {'id': str(channel_id)}}
+            return self.request(r, json=payload, reason=reason)
         return self.request(r, reason=reason)
 
     def create_channel(
@@ -477,7 +488,7 @@ class HTTPClient:
             embed: Optional[Union[Embed, EmbedPayload]],
             *,
             tts: bool = False,
-            message_id: Optional[message.MessageReference],
+            message_id: str,
             message_reference: Optional[message.MessageReference] = None,
             direct=False
     ) -> Response[message.Message]:
@@ -495,7 +506,7 @@ class HTTPClient:
             payload['tts'] = True
 
         if message_id:
-            payload['msg_id'] = message_id['message_id']
+            payload['msg_id'] = message_id
 
         if image_url:
             payload['image'] = image_url
@@ -524,9 +535,6 @@ class HTTPClient:
         r = Route('GET', '/guilds/{guild_id}/members', guild_id=guild_id)
         return self.request(r, params=params)
 
-    def get_all_guild_channels(self, guild_id: int) -> Response[List[guild.GuildChannel]]:
-        return self.request(Route('GET', '/guilds/{guild_id}/channels', guild_id=guild_id))
-
     def get_member(self, guild_id: int, member_id: int) -> Response[member.MemberWithUser]:
         return self.request(
             Route('GET', '/guilds/{guild_id}/members/{member_id}', guild_id=guild_id, member_id=member_id))
@@ -596,6 +604,22 @@ class HTTPClient:
         r = Route('PATCH', '/guilds/{guild_id}/members/{user_id}/mute', guild_id=guild_id, user_id=user_id)
         return self.request(r, json=payload, reason=reason)
 
+    def mute_members(
+            self, user_id: List[int],
+            guild_id: int,
+            duration: Union[datetime.datetime, int],
+            reason: Optional[str] = None
+    ) -> Response[None]:
+        payload: Dict[str, Any] = {'user_ids': user_id}
+
+        if isinstance(duration, datetime.datetime):
+            payload['mute_end_timestamp'] = str(int(duration.timestamp() * 1000))
+        else:
+            payload['mute_seconds'] = str(duration)
+
+        r = Route('PATCH', '/guilds/{guild_id}/mute', guild_id=guild_id)
+        return self.request(r, json=payload, reason=reason)
+
     def mute_guild(
             self, guild_id: int, duration: Union[datetime.datetime, int], reason: Optional[str] = None
     ) -> Response[None]:
@@ -750,3 +774,16 @@ class HTTPClient:
             id=id
         )
         return self.request(r)
+
+    def send_guide(
+            self,
+            channel_id: int,
+            content: str,
+    ):
+        r = Route(
+            'POST',
+            '/channels/{channel_id}/settingguide',
+            channel_id=channel_id
+        )
+        payload = {'content': content}
+        return self.request(r, json=payload)
